//[mahjong-utils](../../../index.md)/[mahjongutils.shanten](../index.md)/[ShantenWithFuroChance](index.md)/[shantenNum](shanten-num.md)

# shantenNum

[common]\
open override val [shantenNum](shanten-num.md): [Int](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-int/index.html)

向听数
